Package: shinyChakraUI
Title: A Wrapper of the 'React' Library 'Chakra UI' for 'Shiny'
Version: 1.1.1
Authors@R: c(
    person(given = "Stéphane",
           family = "Laurent",
           role = c("aut", "cre"),
           email = "laurent_step@outlook.fr"),
    person(given = "Segun",
           family = "Adebayo",
           role = "cph",
           comment = "'Chakra UI' library (https://chakra-ui.com/)"),
    person(given = "David",
           family = "Kaye",
           role = "ctb",
           comment = "'json-normalize.js'"),
    person(given = "RubyLouvre",
           role = "cph",
           comment = "'jsx-parser' library"),
    person(given = "Terence",
           family = "Eden",
           role = "cph",
           comment = "'SuperTinyIcons' library (https://github.com/edent/SuperTinyIcons/)"),
    person(given = "Ionic (http://ionic.io/)",
           role = "cph"))       
Description: Makes the 'React' library 'Chakra UI' usable in 'Shiny' apps. 'Chakra UI' components include alert dialogs, drawers (sliding panels), menus, modals, popovers, sliders, and more. 
License: GPL (>= 3)
Encoding: UTF-8
URL: https://github.com/stla/shinyChakraUI
BugReports: https://github.com/stla/shinyChakraUI/issues
RoxygenNote: 7.1.2
Imports: htmltools, reactR, shiny, jsonlite, rlang, stringr, grDevices,
        utils, formatR, fontawesome
Suggests: testthat (>= 3.0.0), V8
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2022-01-05 14:51:52 UTC; SDL96354
Author: Stéphane Laurent [aut, cre],
  Segun Adebayo [cph] ('Chakra UI' library (https://chakra-ui.com/)),
  David Kaye [ctb] ('json-normalize.js'),
  RubyLouvre [cph] ('jsx-parser' library),
  Terence Eden [cph] ('SuperTinyIcons' library
    (https://github.com/edent/SuperTinyIcons/)),
  Ionic (http://ionic.io/) [cph]
Maintainer: Stéphane Laurent <laurent_step@outlook.fr>
Repository: CRAN
Date/Publication: 2022-01-05 15:30:06 UTC
Built: R 4.6.0; ; 2026-04-28 21:15:10 UTC; unix
