# Generated by roxygen2: do not edit by hand

S3method("$",ReactTagBuilder)
S3method("[[",ReactTagBuilder)
export(Tag)
export(chakraAlertDialog)
export(chakraAlertDialogOptions)
export(chakraCheckboxWithChildren)
export(chakraColorSchemes)
export(chakraCombinedSlider)
export(chakraComponent)
export(chakraDrawer)
export(chakraDrawerOptions)
export(chakraExample)
export(chakraExamples)
export(chakraIcons)
export(chakraModal)
export(chakraModalOptions)
export(chakraPage)
export(chakraPinInput)
export(chakraRangeSlider)
export(chakraSlider)
export(createStandaloneToast)
export(getHookProperty)
export(getState)
export(ionIcons)
export(jseval)
export(jsx)
export(jsxString2code)
export(numberInputOptions)
export(setReactState)
export(sliderMarkOptions)
export(sliderThumbOptions)
export(sliderTooltipOptions)
export(superTinyIcons)
export(useClipboard)
export(useDisclosure)
export(useRef)
export(useToast)
export(withStates)
importFrom(fontawesome,fa_html_dependency)
importFrom(formatR,tidy_source)
importFrom(grDevices,col2rgb)
importFrom(grDevices,rgb)
importFrom(htmltools,HTML)
importFrom(htmltools,attachDependencies)
importFrom(htmltools,htmlDependencies)
importFrom(htmltools,htmlDependency)
importFrom(htmltools,parseCssColors)
importFrom(htmltools,tag)
importFrom(htmltools,tags)
importFrom(htmltools,validateCssUnit)
importFrom(jsonlite,fromJSON)
importFrom(jsonlite,toJSON)
importFrom(reactR,createReactShinyInput)
importFrom(rlang,dots_list)
importFrom(shiny,registerInputHandler)
importFrom(shiny,runApp)
importFrom(stringr,str_trim)
importFrom(utils,URLdecode)
importFrom(utils,URLencode)
